import boto3
from datetime import datetime, timedelta
from aws_monitoring.config import AWSConfig


class AWSCostMonitor():
    def __init__(self, config: AWSConfig = AWSConfig()) -> None:
        self.client = boto3.client(
            'ce', region_name=config.DEFAULT_REGIONS[0], aws_access_key_id=config.AWS_ACCESS_KEY_ID, aws_secret_access_key=config.AWS_SECRET_ACCESS_KEY)

    def get_cost_and_usage(self, start: str, end: str, granularity: str, metrics: list, group_by: list) -> dict:
        response = self.client.get_cost_and_usage(
            TimePeriod={
                'Start': start,
                'End': end
            },
            Granularity=granularity,
            Metrics=metrics,
            GroupBy=[{'Type': 'COST_CATEGORY', 'Key': item}
                     for item in group_by]
        )
        return response





from aws_monitoring import AWSCostMonitor
import datetime
from datetime import timedelta

cost = AWSCostMonitor()


data = cost.get_cost_and_usage(start='2024-01-01', end='2024-06-30',
                     granularity='MONTHLY', metrics=['BlendedCost'], group_by=[])

print(data)
print('\n\n\n')

# Get the costs for the last 30 days
end_date = datetime.datetime.now()
start_date = end_date - timedelta(days=30)

data = cost.get_cost_and_usage(start=start_date.strftime('%Y-%m-%d'), end=end_date.strftime('%Y-%m-%d'),
                     granularity='DAILY', metrics=['BlendedCost'], group_by=[])

# Get The costs for last 30 days and group them by service
end_date = datetime.datetime.now()
start_date = end_date - timedelta(days=30)
data = cost.get_cost_and_usage(start=start_date.strftime('%Y-%m-%d'), end=end_date.strftime('%Y-%m-%d'),
                     granularity='DAILY', metrics=['BlendedCost'], group_by=["Service","Linked account"])
